package org.rcisoft.sys.messageinstance.controller;


import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;

import javax.validation.Valid;

import org.rcisoft.sys.messageinstance.entity.MessageInstance;
import org.rcisoft.sys.messageinstance.service.MessageInstanceService;


/**
 * Created by cy on 2022年11月16日 下午4:37:10.
 */
@RestController
@RequestMapping("/messageInstance")
public class MessageInstanceController extends CyPaginationController<MessageInstance> {


    @Autowired
    private MessageInstanceService messageInstanceServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:sageInstance:add')")
    @CyOpeLogAnno(title = "system-用户消息表管理-新增用户消息表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value = "添加用户消息表", notes = "添加用户消息表")
    @PostMapping(value = "/add")
    public CyResult add(@Valid MessageInstance messageInstance, BindingResult bindingResult) {
        CyPersistModel data = messageInstanceServiceImpl.persist(messageInstance);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                messageInstance);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:sageInstance:delete')")
    @CyOpeLogAnno(title = "system-用户消息表管理-删除用户消息表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "逻辑删除用户消息表", notes = "逻辑删除用户消息表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable int businessId, MessageInstance messageInstance) {
        messageInstance.setBusinessId(businessId);
        CyPersistModel data = messageInstanceServiceImpl.removeLogical(messageInstance);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:sageInstance:delete')")
    @CyOpeLogAnno(title = "system-用户消息表管理-删除用户消息表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "删除用户消息表", notes = "删除用户消息表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable int businessId, MessageInstance messageInstance) {
        messageInstance.setBusinessId(businessId);
        CyPersistModel data = messageInstanceServiceImpl.remove(messageInstance);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:sageInstance:update')")
    @CyOpeLogAnno(title = "system-用户消息表管理-修改用户消息表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value = "修改用户消息表", notes = "修改用户消息表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable int businessId, @Valid MessageInstance messageInstance, BindingResult bindingResult) {
        messageInstance.setBusinessId(businessId);
        CyPersistModel data = messageInstanceServiceImpl.merge(messageInstance);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                messageInstance);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:sageInstance:query')")
    @CyOpeLogAnno(title = "system-用户消息表管理-查询用户消息表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询单一用户消息表", notes = "查询单一用户消息表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable int businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                messageInstanceServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:sageInstance:list')")
    @CyOpeLogAnno(title = "system-用户消息表管理-查询用户消息表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询用户消息表集合", notes = "查询用户消息表集合")
    @GetMapping(value = "/queryMessageInstances")
    public CyResult queryMessageInstances(MessageInstance messageInstance) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                messageInstanceServiceImpl.findAll(messageInstance));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:sageInstance:list')")
    @CyOpeLogAnno(title = "system-用户消息表管理-查询用户消息表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "分页查询用户消息表集合", notes = "分页查询用户消息表集合")
    @GetMapping(value = "/queryMessageInstanceByPagination")
    public CyGridModel listByPagination(MessageInstance messageInstance) {
        messageInstanceServiceImpl.findAllByPagination(getPaginationUtility(), messageInstance);
        return getGridModelResponse();
    }

}
