package org.rcisoft.sys.ossinfo.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;


import org.rcisoft.sys.ossinfo.entity.OssInfo;
import org.rcisoft.sys.ossinfo.service.OssInfoService;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

/**
* Created by cy on 2022年11月21日 上午11:18:04.
*/
@RestController
@RequestMapping("/ossInfo")
public class OssInfoController extends CyPaginationController<OssInfo> {


    @Autowired
    private OssInfoService ossInfoServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:info:add')")
    @CyOpeLogAnno(title = "system-文件存储表管理-新增文件存储表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加文件存储表", notes="添加文件存储表")
    @PostMapping(value = "/add")
    public CyResult add(@Valid OssInfo ossInfo, BindingResult bindingResult) {
        CyPersistModel data = ossInfoServiceImpl.persist(ossInfo);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        ossInfo);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:info:delete')")
    @CyOpeLogAnno(title = "system-文件存储表管理-删除文件存储表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除文件存储表", notes="删除文件存储表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable int businessId,OssInfo ossInfo) {
        ossInfo.setBusinessId(businessId);
        CyPersistModel data = ossInfoServiceImpl.remove(ossInfo);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:info:update')")
    @CyOpeLogAnno(title = "system-文件存储表管理-修改文件存储表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改文件存储表", notes="修改文件存储表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable int businessId, @Valid OssInfo ossInfo, BindingResult bindingResult) {
        ossInfo.setBusinessId(businessId);
        CyPersistModel data = ossInfoServiceImpl.merge(ossInfo);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        ossInfo);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:info:query')")
    @CyOpeLogAnno(title = "system-文件存储表管理-查询文件存储表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一文件存储表", notes="查询单一文件存储表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable int businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        ossInfoServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:info:list')")
    @CyOpeLogAnno(title = "system-文件存储表管理-查询文件存储表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询文件存储表集合", notes="查询文件存储表集合")
    @GetMapping(value = "/queryOssInfos")
    public CyResult queryOssInfos(OssInfo ossInfo) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            ossInfoServiceImpl.findAll(ossInfo));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:info:list')")
    @CyOpeLogAnno(title = "system-文件存储表管理-查询文件存储表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询文件存储表集合", notes="分页查询文件存储表集合")
    @GetMapping(value = "/queryOssInfoByPagination")
    public CyGridModel listByPagination(OssInfo ossInfo) {
        ossInfoServiceImpl.findAllByPagination(getPaginationUtility(), ossInfo);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-文件存储表管理-查询文件存储表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出文件存储表信息", notes = "导出文件存储表信息")
    @GetMapping(value = "/export")
    public CyResult outOssInfo(HttpServletResponse response,OssInfo ossInfo,@PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="文件存储表信息.xls";break;
            case "1": excelName="文件存储表信息.xlsx";break;
            case "2": excelName="文件存储表信息.csv";break;
        }
        List<OssInfo> ossInfoList = ossInfoServiceImpl.export(ossInfo);
        CyEpExcelUtil.exportExcel(ossInfoList, "文件存储表信息", "文件存储表信息", OssInfo.class, excelName, response);
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            ossInfoList);
    }

    /**
     * 文件上传
     *
     * @param file
     * @return
     */
    @ApiOperation(value = "文件上传", notes = "文件上传")
    @ApiImplicitParams({@ApiImplicitParam(name = "file", value = "文件", required = true, dataType = "file")})
    @PostMapping(value = "/fileUpload")
    @ResponseBody
    public CyResult comFileUpload(@RequestParam("file") MultipartFile file, @RequestParam("temp") String temp) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                ossInfoServiceImpl.filePath(file, temp));
    }
}
