package org.rcisoft.sys.sysuser.controller;


/*固定导入*/

import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import oracle.jdbc.proxy.annotation.Post;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.sys.sysuser.entity.DoorRecord;
import org.rcisoft.sys.sysuser.service.DoorRecordService;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.exception.CyServiceException;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;


import java.util.List;

/**
 * Created by cy on 年11月24日 下午12:47:46.
 */
@RestController
@RequestMapping("/doorrecord")
public class DoorRecordController extends CyPaginationController<DoorRecord> {


    @Autowired
    private DoorRecordService doorRecordServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:rRecord:add')")
    @CyOpeLogAnno(title = "system-通行记录信息表管理-新增通行记录信息表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value = "添加通行记录信息表", notes = "添加通行记录信息表")
    @PostMapping(value = "/add")
    public CyResult add(@Valid DoorRecord doorRecord, BindingResult bindingResult) {
        CyPersistModel data = doorRecordServiceImpl.persist(doorRecord);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                doorRecord);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:rRecord:delete')")
    @CyOpeLogAnno(title = "system-通行记录信息表管理-删除通行记录信息表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "逻辑删除通行记录信息表", notes = "逻辑删除通行记录信息表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable String businessId, DoorRecord doorRecord) {
        doorRecord.setBusinessId(businessId);
        CyPersistModel data = doorRecordServiceImpl.removeLogical(doorRecord);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:rRecord:delete')")
    @CyOpeLogAnno(title = "system-通行记录信息表管理-删除通行记录信息表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "删除通行记录信息表", notes = "删除通行记录信息表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable String businessId, DoorRecord doorRecord) {
        doorRecord.setBusinessId(businessId);
        CyPersistModel data = doorRecordServiceImpl.remove(doorRecord);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:rRecord:update')")
    @CyOpeLogAnno(title = "system-通行记录信息表管理-修改通行记录信息表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value = "修改通行记录信息表", notes = "修改通行记录信息表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update")
    public CyResult update(@RequestBody DoorRecord doorRecord, BindingResult bindingResult) {
        CyPersistModel data = doorRecordServiceImpl.merge(doorRecord);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                doorRecord);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:rRecord:query')")
    @CyOpeLogAnno(title = "system-通行记录信息表管理-查询通行记录信息表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询单一通行记录信息表", notes = "查询单一通行记录信息表")
    @ApiImplicitParams({@ApiImplicitParam(name = "userId", value = "userId", required = true, dataType = "varchar")})
    @PostMapping("/detail")
    public CyResult detail(@RequestBody DoorRecord doorRecord) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                doorRecordServiceImpl.findById(doorRecord));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:rRecord:list')")
    @CyOpeLogAnno(title = "system-通行记录信息表管理-查询通行记录信息表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询通行记录信息表集合", notes = "查询通行记录信息表集合")
    @GetMapping(value = "/queryDoorRecords")
    public CyResult queryDoorRecords(DoorRecord doorRecord) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                doorRecordServiceImpl.findAll(doorRecord));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:rRecord:list')")
    @CyOpeLogAnno(title = "system-通行记录信息表管理-查询通行记录信息表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "分页查询通行记录信息表集合", notes = "分页查询通行记录信息表集合")
    @GetMapping(value = "/queryDoorRecordByPagination")
    public CyGridModel listByPagination(DoorRecord doorRecord) {
        doorRecordServiceImpl.findAllByPagination(getPaginationUtility(), doorRecord);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-通行记录信息表管理-查询通行记录信息表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出通行记录信息表信息", notes = "导出通行记录信息表信息")
    @GetMapping(value = "/export")
    public CyResult outDoorRecord(HttpServletResponse response, DoorRecord doorRecord, @PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName = "";
        switch (excelId) {
            case "0":
                excelName = "通行记录信息表信息.xls";
                break;
            case "1":
                excelName = "通行记录信息表信息.xlsx";
                break;
            case "2":
                excelName = "通行记录信息表信息.csv";
                break;
        }
        List<DoorRecord> doorRecordList = doorRecordServiceImpl.export(doorRecord);
        CyEpExcelUtil.exportExcel(doorRecordList, "通行记录信息表信息", "通行记录信息表信息", DoorRecord.class, excelName, response);
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                doorRecordList);
    }
}
