package org.rcisoft.sys.sysuser.controller;


/*固定导入*/

import cn.hutool.core.codec.Base64Encoder;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.core.anno.CyEptSm4EnableAnno;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.result.enums.CyReSysExcEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.core.util.CyQrCodeUtil;
import org.rcisoft.sys.sysuser.dao.SysUserRepositorys;
import org.rcisoft.sys.sysuser.dto.ExportUserDTO;
import org.rcisoft.sys.sysuser.entity.SysUser;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;

import javax.imageio.ImageIO;
import javax.servlet.http.HttpServletResponse;

import org.rcisoft.sys.sysuser.service.SysUserService;
import org.springframework.web.multipart.MultipartFile;

import java.awt.image.BufferedImage;
import java.io.ByteArrayOutputStream;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * Created by cy on 2022年11月16日 下午3:19:19.
 */
@RestController
@RequestMapping("/sysUserManage")
public class SysUserController extends CyPaginationController<SysUser> {


    @Autowired
    private SysUserService sysUserServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:user:add')")
    @CyOpeLogAnno(title = "system-用户表管理-新增用户表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value = "添加用户表", notes = "添加用户表")
    @PostMapping(value = "/add")
    public CyResult add(@RequestBody SysUser sysUser, BindingResult bindingResult) {
        sysUser.setUserType("0");
        CyPersistModel data = sysUserServiceImpl.persist(sysUser);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUser);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:user:delete')")
    @CyOpeLogAnno(title = "system-用户表管理-删除用户表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "逻辑删除用户表", notes = "逻辑删除用户表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable int businessId, SysUser sysUser) {
        sysUser.setBusinessId(businessId);
        CyPersistModel data = sysUserServiceImpl.removeLogical(sysUser);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    //逻辑删除
    //@PreAuthorize("@cyPerm.hasPerm('sys:user:delete')")
    @CyOpeLogAnno(title = "system-用户表管理-删除用户表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "删除用户表", notes = "删除用户表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable int businessId, SysUser sysUser) {
        sysUser.setBusinessId(businessId);
        CyPersistModel data = sysUserServiceImpl.remove(sysUser);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:user:update')")
    @CyOpeLogAnno(title = "system-用户表管理-修改用户表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value = "修改用户表", notes = "修改用户表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update")
    public CyResult update(@RequestBody SysUser sysUser, BindingResult bindingResult) {
        CyPersistModel data = sysUserServiceImpl.merge(sysUser);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUser);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:user:query')")
    @CyOpeLogAnno(title = "system-用户表管理-查询用户表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询单一用户表", notes = "查询单一用户表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable Integer businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUserServiceImpl.findById(businessId));
    }

    //    //@PreAuthorize("@cyPerm.hasPerm('sys:user:list')")
    @CyOpeLogAnno(title = "system-用户表管理-查询用户表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询用户表集合", notes = "查询用户表集合")
    @GetMapping(value = "/querySysUsers")
    public CyResult querySysUsers(SysUser sysUser) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUserServiceImpl.findAll(sysUser));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:user:list')")
    @CyOpeLogAnno(title = "system-用户表管理-查询用户表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "分页查询用户表集合", notes = "分页查询用户表集合")
    @GetMapping(value = "/querySysUserByPagination")
    public CyGridModel listByPagination(SysUser sysUser) {
        sysUser.setUserType("0");
        System.out.println(sysUser);
        sysUserServiceImpl.findAllByPagination(getPaginationUtility(), sysUser);
        return getGridModelResponse();
    }

    //查询数据字典
    @GetMapping(value = "/queryData/{dictType:\\w+}")
    public CyResult queryData(SysUser sysUser) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUserServiceImpl.findAllByData(sysUser));
    }

    //查询部门
    @GetMapping(value = "/queryDept")
    public CyResult queryDept(SysUser sysUser) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUserServiceImpl.findAllByDept(sysUser));
    }

    @CyOpeLogAnno(title = "system-用户表管理-查询用户表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出用户表信息", notes = "导出用户表信息")
    @GetMapping(value = "/export")
    public CyResult outSysUser(HttpServletResponse response, SysUser sysUser, @PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName = "";
        switch (excelId) {
            case "0":
                excelName = "用户表信息.xls";
                break;
            case "1":
                excelName = "用户表信息.xlsx";
                break;
            case "2":
                excelName = "用户表信息.csv";
                break;
        }
        List<SysUser> sysUserList = sysUserServiceImpl.export(sysUser);
        CyEpExcelUtil.exportExcel(sysUserList, "用户表信息", "用户表信息", SysUser.class, excelName, response);
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUserList);
    }

    @CyOpeLogAnno(title = "system-用户管理-导入用户", businessType = CyLogTypeEnum.IMPORT)
    @ApiOperation(value = "导入用户信息", notes = "导入用户信息")
    @PostMapping("/import")
    @CyEptSm4EnableAnno
    public CyResult importSysUsers(@RequestBody MultipartFile file, ExportUserDTO exportUserDTO) {
        List<ExportUserDTO> exportUserDTOS = CyEpExcelUtil.importExcel(file, 0, 3, ExportUserDTO.class);
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUserServiceImpl.importSysUsers(exportUserDTOS));
    }

    @CyOpeLogAnno(title = "system-用户管理-导出用户", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出用户信息空模板", notes = "导出用户信息空模板")
    @GetMapping(value = "/importTemplate")
    @CyEptSm4EnableAnno
    public CyResult outSysUserEmpty(HttpServletResponse response) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUserServiceImpl.exportEmptyTemplate(response));
    }

    @CyOpeLogAnno(title = "system-用户管理-导入用户", businessType = CyLogTypeEnum.IMPORT)
    @ApiOperation(value = "导入用户信息", notes = "导入用户信息")
    @PostMapping("/importExcel")
    @CyEptSm4EnableAnno
    public CyResult importSysUser(MultipartFile file) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUserServiceImpl.importUserExcel(file));
    }

    /**
     * 获取 二维码接口地址
     * 配置文件需要 配置 前缀
     *
     * @param businessId
     * @return
     * @deprecated 前端生成 二维码
     * 后端返回  base64
     */
    @GetMapping("/getTradeScan/{businessId:\\w+}")
    @ResponseBody
    public CyResult getTradeScan(@PathVariable Integer businessId) {
        String codeUrl = "sysUserServiceImpl.findById(businessId).toString()";
        String png_base64 = null;
        //返回二维码 并且构造支付包web支付对象
        ByteArrayOutputStream baOp = new ByteArrayOutputStream();
        try {
            BufferedImage bufImg = CyQrCodeUtil.qRCodeCommon(codeUrl);
            // 生成二维码QRCode图片
            ImageIO.write(bufImg, "png", baOp);
            byte[] bytes = baOp.toByteArray();//转换成字节
            /**
             * jdk 17 替代方案
             */
            png_base64 = Base64Encoder.encode(bytes).trim();
            png_base64 = png_base64.replaceAll("\n", "").replaceAll("\r", "");//删除 \r\n
        } catch (Exception e) {
            throw new CyServiceException(CyReSysExcEnum.ERROR);
        }
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                png_base64);
    }

}
