package org.rcisoft.sys.sysuser.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.rcisoft.common.component.CyGlobal;
import org.rcisoft.core.component.CyDownErrorTxtComp;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.result.enums.CyResSvcExcEnum;
import org.rcisoft.core.util.CyCompareToolUtils;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyPersistModel;

import org.rcisoft.sys.constant.CyDictCons;
import org.rcisoft.sys.dictionary.entity.DictData;
import org.rcisoft.sys.dictionary.service.DictionaryService;
import org.rcisoft.sys.rbac.user.dto.ImportUserDTO;
import org.rcisoft.sys.sysuser.dao.SysDeptRepositorys;
import org.rcisoft.sys.sysuser.dao.SysDictDataRepositorys;
import org.rcisoft.sys.sysuser.dao.SysUserRepositorys;
import org.rcisoft.sys.sysuser.dao.SysUserRoleRepository;
import org.rcisoft.sys.sysuser.dto.ExcelDTO;
import org.rcisoft.sys.sysuser.dto.ExportUserDTO;
import org.rcisoft.sys.sysuser.entity.SysDept;
import org.rcisoft.sys.sysuser.entity.SysDictData;
import org.rcisoft.sys.sysuser.entity.SysUser;
import org.rcisoft.sys.sysuser.entity.SysUserRole;
import org.rcisoft.sys.sysuser.service.SysUserService;
import org.rcisoft.sys.sysuser.util.CheckUtil;
import org.rcisoft.sys.sysuser.util.CyEpExcelUtil;
import org.rcisoft.sys.wbac.user.dto.ErrorDTO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.security.crypto.password.PasswordEncoder;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.rcisoft.core.model.CyPageInfo;

import java.lang.reflect.Field;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;

import lombok.extern.slf4j.Slf4j;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;

/**
 * Created by cy on 2022年11月16日 下午3:19:19.
 */
@Service
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class SysUserServiceImpl extends ServiceImpl<SysUserRepositorys, SysUser> implements SysUserService {
    @Autowired
    private SysUserRepositorys sysUserRepositorys;
    @Autowired
    private SysDeptRepositorys sysDeptRepositorys;
    @Autowired
    private SysDictDataRepositorys sysDictDataRepositorys;
    @Autowired
    private DictionaryService dictionaryService;
    @Autowired
    private CyDownErrorTxtComp errorTxt;
    @Autowired
    private CyGlobal global;
    @Autowired
    private SysUserRoleRepository sysUserRoleRepository;
    @Autowired
    private PasswordEncoder passwordEncoder;
    @Value("${cy.init.password}")
    private String password;

    /**
     * 保存 用户表
     *
     * @param sysUser
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(SysUser sysUser) {

        // 判断是否为访客
        if (sysUser.getUserType().equals("1")) {
            List<SysUser> userList = sysUserRepositorys.querySysUsersByPhone(sysUser.getPhone());
            if (userList.size() == 0) {
                sysUserRepositorys.addSysUsers(sysUser);
            } else {
                for (SysUser u : userList) {
                    u.setName(sysUser.getName());
                    sysUserRepositorys.updateSysUser(u);
                }
            }
            return new CyPersistModel(1);
        }

//        //查询是否重名
//        if (sysUserRepositorys.querySysUsersByName(sysUser.getName()).size() >= 1) {
//            throw new CyServiceException(500, "姓名已存在");
//        }
        //判断是否添加为管理员
        if (sysUser.getIdentity().equals("2")) {
            //添加账号为手机号
            sysUser.setUsername(sysUser.getPhone());
            //查询是否有重复用户名
            if (sysUserRepositorys.querySysUsersByUserName(sysUser.getUsername()).size() >= 1) {
                throw new CyServiceException(500, "用户名已存在");
            }
            //添加密码
            sysUser.setPassword(this.passwordEncoder.encode(this.password));
            sysUserRepositorys.addSysUsers(sysUser);
            List<SysUser> sysUsers = sysUserRepositorys.querySysUsersByName(sysUser.getName());
            if (sysUser.getRoleList() != null && sysUser.getRoleList().size() > 0) {
                for (int i = 0; i < sysUser.getRoleList().size(); i++) {
                    SysUserRole sysUserRole = new SysUserRole();
                    sysUserRole.setUserId(sysUsers.get(0).getBusinessId());
                    sysUserRole.setRoleId((Integer) sysUser.getRoleList().get(i));
                    sysUserRoleRepository.addRoles(sysUserRole);
                }
            }
        } else {
            //查询已有手机号
            if (sysUserRepositorys.querySysUsersByPhone(sysUser.getPhone()).size() >= 1) {
                throw new CyServiceException(500, "手机号已存在");
            }
            //添加所属园区中文
            sysUser.setAddressLabel(sysUser.getAddressLabel());
            //添加职位中文
            sysUser.setPositionLabel(sysUser.getPositionLabel());
            //添加班次中文
            sysUser.setNltBzLabel(sysUser.getNltBzLabel());
            //添加用户名
            sysUser.setUsername(sysUser.getPhone());
            //添加身份
            sysUser.setIdentity("1");
            sysUserRepositorys.addSysUsers(sysUser);
        }
        log.debug(CyUserUtil.getAuthenUsername() + "新增了ID为" +
                sysUser.getBusinessId() + "的用户表信息");
        return new CyPersistModel(1);
    }

    /**
     * 删除 用户表
     *
     * @param sysUser
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(SysUser sysUser) {
        int line = sysUserRepositorys.delSysUser(Long.valueOf(sysUser.getBusinessId()));
        log.debug(CyUserUtil.getAuthenUsername() + "删除了ID为" +
                sysUser.getBusinessId() + "的用户表信息");
        return new CyPersistModel(line);
    }

    /**
     * 逻辑删除 用户表
     *
     * @param sysUser
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(SysUser sysUser) {
        sysUser.setDeleted();
        int line = baseMapper.deleteById(sysUser);
        log.debug(CyUserUtil.getAuthenUsername() + "逻辑删除了ID为" +
                sysUser.getBusinessId() + "的用户表信息");
        return new CyPersistModel(line);
    }

    /**
     * 修改 用户表
     *
     * @param sysUser
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(SysUser sysUser) {
        if (sysUser.getFenZhi() != null) {
            if (!sysUser.getFenZhi().equals("2")) {
                //查询是否有重复用户名
                if (sysUserRepositorys.querySysUsersByUserName(sysUser.getUsername()).size() > 1) {
                    throw new CyServiceException(500, "用户名已存在");
                }
                //查询已有手机号
                if (sysUserRepositorys.querySysUsersByPhone(sysUser.getPhone()).size() > 1) {
                    throw new CyServiceException(500, "手机号已存在");
                }
            }
        }
        //添加用户名
        sysUser.setUsername(sysUser.getPhone());
        //添加密码
        sysUser.setPassword(this.passwordEncoder.encode(this.password));
        int line = sysUserRepositorys.updateSysUser(sysUser);
        //更新角色
        sysUserRoleRepository.delRoles(sysUser.getBusinessId());
        SysUserRole sysUserRole = new SysUserRole();
        if (sysUser.getRoleList() != null && sysUser.getRoleList().size() > 0) {
            for (int i = 0; i < sysUser.getRoleList().size(); i++) {
                sysUserRole.setRoleId((Integer) sysUser.getRoleList().get(i));
                sysUserRole.setUserId(sysUser.getBusinessId());
                sysUserRoleRepository.addRoles(sysUserRole);
            }
        }

        log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + sysUser.getBusinessId() + "的用户表信息");
        return new CyPersistModel(line);
    }

    /**
     * 根据id查询 用户表
     *
     * @param businessId
     * @return
     */
    @Override
    public SysUser findById(Integer businessId) {

        SysUser user = sysUserRepositorys.querySysUsersById(businessId);
        //角色集合转换为数组
        List<SysUserRole> sysUserRoles = sysUserRoleRepository.querySysUserRolesById(businessId);
        if (sysUserRoles.size() != 0) {
            List<Integer> roleIds = sysUserRoles.stream().map(SysUserRole::getRoleId).collect(Collectors.toList());
            user.setRoleList(roleIds);
        }
        //查询上级部门
        if (user.getDeptId() != null) {
            List<SysDept> sysDepts = sysDeptRepositorys.queryDeptBySJ(user.getDeptId());
            Integer[] arr = new Integer[sysDepts.size() + 1];
            if (sysDepts.size() != 0) {
                for (int i = 0; i <= sysDepts.size(); i++) {
                    if (i == sysDepts.size()) {
                        arr[i] = Integer.valueOf(user.getDeptId());
                        break;
                    }
                    arr[i] = sysDepts.get(i).getBusinessId();
                }
                user.setDeptSJ(List.of(arr));
            }
        }


        return user;
    }

    /**
     * 分页查询 用户表
     *
     * @param sysUser
     * @return
     */
    @Override
    public IPage<SysUser> findAllByPagination(CyPageInfo<SysUser> paginationUtility, SysUser sysUser) {
        //管理员信息查询
        if (sysUser.getFenZhi() != null) {
            if (sysUser.getFenZhi().equals("2")) {
                IPage<SysUser> sysUserIPage = baseMapper.querySysUsersByFenZhi2(paginationUtility, sysUser);
//            //查询角色集合
//            for (int i = 0; i < sysUserIPage.getRecords().size(); i++) {
//                //角色
//                List<SysUserRole> sysUserRoles = sysUserRoleRepository.querySysUserRolesById(sysUserIPage.getRecords().get(i).getBusinessId());
//                List<Integer> roleIds = sysUserRoles.stream().map(SysUserRole::getRoleId).collect(Collectors.toList());
//                sysUserIPage.getRecords().get(i).setRoleList(roleIds);
//            }
                return sysUserIPage;

            }
        }

        IPage<SysUser> sysUserIPage = baseMapper.querySysUsersPaged(paginationUtility, sysUser);
        for (int i = 0; i < sysUserIPage.getRecords().size(); i++) {
            String deptId = sysUserIPage.getRecords().get(i).getDeptId();
            //根据部门id查询部门表
            List<SysDept> sysDepts = sysDeptRepositorys.queryDeptById(deptId);
            if (sysDepts.size() != 0) {
                //获取部门名称
                String deptName = sysDepts.get(0).getDeptName();
                sysUserIPage.getRecords().get(i).setDeptName(deptName);
            }

            //查询职位id
            String position = sysUserIPage.getRecords().get(i).getPosition();
            List<SysDictData> sysDictData = sysDictDataRepositorys.queryDataByPosition(position);
            if (sysDictData.size() != 0) {
                //查询职位中文名
                String dictLabel = sysDictData.get(0).getDictLabel();
                //查询权重
                Integer dictSort = sysDictData.get(0).getDictSort();
                sysUserIPage.getRecords().get(i).setDictLabelByPosition(dictLabel);
                sysUserIPage.getRecords().get(i).setDictSort(dictSort);
            }

            //查询班次id
            String nltBz = sysUserIPage.getRecords().get(i).getNltBz();
            List<SysDictData> sysDictData1 = sysDictDataRepositorys.queryDataByNltBz(nltBz);
            if (sysDictData1.size() != 0) {
                //查询班次中文名
                String dictLabel = sysDictData1.get(0).getDictLabel();
                sysUserIPage.getRecords().get(i).setDictLabelBynltBz(dictLabel);
            }


        }

        return sysUserIPage;
    }

    /**
     * 查询list 用户表
     *
     * @param sysUser
     * @return
     */
    @Override
    public List<SysUser> findAll(SysUser sysUser) {
        return baseMapper.querySysUsers(sysUser);

    }

    @Override
    public List<SysUser> getList() {
        List<SysUser> sysUserList = baseMapper.getUserList();
        for (SysUser user : sysUserList) {
            String deptId = user.getDeptId();
            if (deptId != null) {
                SysDept dept = sysDeptRepositorys.getDeptById(deptId);
                if (dept != null && dept.getDeptName() != null) {
                    user.setDeptName(dept.getDeptName());
                }
            }
        }
        return sysUserList;
    }

    public SysUser getUserById(Integer id) {
        SysUser user = baseMapper.getUserById(id);
        String deptId = user.getDeptId();
        if (deptId != null) {
            SysDept dept = sysDeptRepositorys.getDeptById(deptId);
            if (dept != null && dept.getDeptName() != null) {
                user.setDeptName(dept.getDeptName());
            }
        }
        return user;
    }

    public List<SysUser> findAllByData(SysUser sysUser) {
        return sysDictDataRepositorys.queryData(sysUser);

    }

    public List<SysUser> findAllByDept(SysUser sysUser) {
        return sysDeptRepositorys.queryDept(sysUser);

    }

    /**
     * 导出用户表
     *
     * @return
     */
    @Override
    public List export(SysUser sysUser) {
        List<SysUser> sysUserList = baseMapper.querySysUsers(sysUser);
        ArrayList<SysUser> list = new ArrayList<>();
        for (int i = 0; i < sysUserList.size(); i++) {
            String deptId = sysUserList.get(i).getDeptId();
            //根据部门id查询部门表
            List<SysDept> sysDepts = sysDeptRepositorys.queryDeptById(deptId);
            if (sysDepts.size() != 0) {
                //获取部门名称
                String deptName = sysDepts.get(0).getDeptName();
                sysUserList.get(i).setDeptId(deptName);
            }

            //查询职位id
            String position = sysUserList.get(i).getPosition();
            List<SysDictData> sysDictData = sysDictDataRepositorys.queryDataByPosition(position);
            if (sysDictData.size() != 0) {
                //查询职位中文名
                String dictLabel = sysDictData.get(0).getDictLabel();
                sysUserList.get(i).setPosition(dictLabel);
            }

            //查询班次id
            String nltBz = sysUserList.get(i).getNltBz();
            List<SysDictData> sysDictData1 = sysDictDataRepositorys.queryDataByNltBz(nltBz);
            if (sysDictData1.size() != 0) {
                //查询班次中文名
                String dictLabel = sysDictData1.get(0).getDictLabel();
                sysUserList.get(i).setNltBz(dictLabel);
            }

            //性别
            if (sysUserList.get(i).getSex() != null) {
                if (sysUserList.get(i).getSex().equals("1")) {
                    sysUserList.get(i).setSex("男");
                } else if (sysUserList.get(i).getSex().equals("0")) {
                    sysUserList.get(i).setSex("女");
                }
            }
            //身份
            if (sysUserList.get(i).getIdentity() != null) {
                if (sysUserList.get(i).getIdentity().equals("1")) {
                    sysUserList.get(i).setIdentity("正式员工");
                }
            }

            list.add(sysUserList.get(i));
        }

        return list;
    }

    @Override
    public int importSysUsers(List<ExportUserDTO> exportUserDTOS) {

        for (int i = 0; i < exportUserDTOS.size(); i++) {
            ExportUserDTO exportUserDTO1 = exportUserDTOS.get(i);
            sysUserRepositorys.addSysUser(exportUserDTO1);
        }
        return 1;
    }

    @Override
    public int exportEmptyTemplate(HttpServletResponse response) {
        List<ExportUserDTO> imOutSysUsers = new ArrayList<>();
        ExportUserDTO exportUserDTO = new ExportUserDTO();
        for (int i = 0; i < 500; i++) {
            imOutSysUsers.add(exportUserDTO);
        }
        // 导出模板需要的下拉列的值
        ExcelDTO excelDto = new ExcelDTO();
        SysDictData sysDictData = new SysDictData();
        sysDictData.setDictType("shift");
        sysDictData.setNormal();
        List<SysDictData> shiftList = sysDictDataRepositorys.querySysDictDatas(sysDictData);
        String[] shift = shiftList.stream().map(SysDictData::getDictLabel).collect(Collectors.toList())
                .toArray(new String[shiftList.size()]);
        excelDto.setShift(shift);
        CyEpExcelUtil.exportExcelSelect(imOutSysUsers, "用户信息", "用户",
                ExportUserDTO.class, "模板.xls", response, excelDto);
        return 1;
    }

    void errorText(String error, ImportUserDTO importUserDTO, List<Map<Integer, List<String>>> maps, String fileName) {
        List<String> strings = new ArrayList<String>();
        strings.add(error);
        Map<Integer, List<String>> map = new HashMap<>();
        map.put(-1, strings);
        maps.add(map);
        importUserDTO.setFilename(fileName);
    }

    @Override
    @Transactional
    public ImportUserDTO importUserExcel(MultipartFile file) {
        ImportUserDTO importUserDTO = new ImportUserDTO();
        Calendar calendar = Calendar.getInstance();
        String nowTime = new SimpleDateFormat("yyyyMMddHHmmss").format(calendar.getTime());
        String fileName = "用户错误信息" + nowTime + ".txt";
        List<Map<Integer, List<String>>> maps = new ArrayList<>();
        ExportUserDTO exportUserDTO = new ExportUserDTO();
        boolean flag = false;
        try {
            flag = CyEpExcelUtil.isFileInUser(file, exportUserDTO, 2);
        } catch (Exception e) {
//            throw new CyServiceException(CyResSvcExcEnum.ERROR_NETWORK);
            throw new CyServiceException(1111, "非模板文件");
        }
        if (!flag){
            throw new CyServiceException(org.rcisoft.sys.visit.entity.CyResSvcExcEnum.EXCEL_IMPORT_HEADER_ERROR);
        }
        if (!flag || !CyCompareToolUtils.compareFileName(file, "用户信息", 0, 0)) {
            String errorBefore = "上传模板错误请重新下载！";
            errorText(errorBefore, importUserDTO, maps, fileName);
            try {
                errorTxt.exportTxtPaper(maps, fileName);
            } catch (Exception e) {
                throw new CyServiceException(CyResSvcExcEnum.ERROR_NETWORK);
            }
            return importUserDTO;
        }
        /** 从excel表中读到数据，有一部分为空值 */
        List<ExportUserDTO> sysUserList = CyEpExcelUtil.importExcel(file, 2, 1, ExportUserDTO.class);
        /** 遍历 从Excel表中读到的数据 抛出不合适的数据 */
        //判断整个Excel是不是为空 计算非空数据有多少条
        int information = CyCompareToolUtils.cmpareInformation(sysUserList);
        if (information == 0) {
            String errorBefore = "Excel文件不可为空，请检查Excel文件是否填写！";
            errorText(errorBefore, importUserDTO, maps, fileName);
            try {
                errorTxt.exportTxtPaper(maps, fileName);
            } catch (Exception e) {
                throw new CyServiceException(CyResSvcExcEnum.ERROR_NETWORK);
            }
            return importUserDTO;
        } else if (information > 500) {
            String errorMore = "单次导入数据不可超过500，请检查！";
            errorText(errorMore, importUserDTO, maps, fileName);
            try {
                errorTxt.exportTxtPaper(maps, fileName);
            } catch (Exception e) {
                throw new CyServiceException(CyResSvcExcEnum.ERROR_NETWORK);
            }
            return importUserDTO;
        } else {
            //去除空数据
            try {
                sysUserList = ThrowNull(sysUserList);
            } catch (Exception e) {
                throw new CyServiceException(CyResSvcExcEnum.ERROR_NETWORK);
            }
            //校验 将错误信息放入maps
            int index = 3; //从第3行开始
            SysUser sysUserDTO = new SysUser();
            sysUserDTO.setDeleted();
            List<SysUser> sysUsers = sysUserRepositorys.querySysUsers(sysUserDTO);
            for (ExportUserDTO sysUser : sysUserList) {
                //判断 是否为空
                ErrorDTO userNull = CheckUtil.userNotNull(sysUser, index);
                if (userNull.getSuccess() == 1) {
                    maps.add(userNull.getMap());
                }
                //判断 信息是否重复
                ErrorDTO userRepeat = CheckUtil.userRepeat(sysUser, index, sysUsers);
                if (userRepeat.getSuccess() == 1) {
                    maps.add(userRepeat.getMap());
                }
                index++;
            }
        }
        /** 将 信息插入sys_user  */
        if (sysUserList.size() > 0) {
            //用户性别数据字典
            List<DictData> userSex = dictionaryService.selectByTypes(CyDictCons.USER_SEX);
            for (ExportUserDTO sysUser : sysUserList) {
                sysUser.setIdentity("0");
                //数据库需要插入的用户信息
                //登录名
                if (sysUser.getUsername() == null) {
                    throw new CyServiceException(500, "数据错误");
                }
                //手机号
                if (sysUser.getPhone() == null) {
                    throw new CyServiceException(500, "数据错误");
                }
                //人脸信息
                if (sysUser.getFaceAddress() == null) {
                    throw new CyServiceException(500, "数据错误");
                }
                //所属园区
                if (sysUser.getAddress() == null) {
                    throw new CyServiceException(500, "数据错误");
                }
                //性别
                if (sysUser.getSex() != null) {
                    if (sysUser.getSex().equals("男")) {
                        sysUser.setSex("0");
                    } else if (sysUser.getSex().equals("女")) {
                        sysUser.setSex("1");
                    } else {
                        throw new CyServiceException(500, "数据错误");
                    }
                } else {
                    throw new CyServiceException(500, "数据错误");
                }

                //所属部门
                SysDept sysDept = sysDeptRepositorys.querySysDeptByName(sysUser.getDeptId());
                if (sysDept == null || sysDept.equals(' ')) {
                    throw new CyServiceException(500, "数据错误");
                } else {
                    sysUser.setDeptId(sysDept.getBusinessId().toString());
                }
                //字典职位
                SysDictData sysDictData1 = sysDictDataRepositorys.queryDataByDeptIdC(sysUser.getPosition());
                if (sysDictData1 == null || sysDictData1.equals(' ')) {
                    throw new CyServiceException(500, "数据错误");
                } else {
                    sysUser.setPosition(sysDictData1.getBusinessId().toString());
                }
                //字典班次
                SysDictData sysDictData2 = sysDictDataRepositorys.queryDataByDeptIdC(sysUser.getNltBz());
                if (sysDictData2 == null || sysDictData2.equals(' ')) {
                    throw new CyServiceException(500, "数据错误");
                } else {
                    sysUser.setNltBz(sysDictData2.getBusinessId().toString());
                }
                //工作状态
                if (sysUser.getFlag() != null) {
                    if (sysUser.getFlag().equals("停用")) {
                        sysUser.setFlag("0");
                    } else if (sysUser.getFlag().equals("正常") || sysUser.getFlag().equals("在职")) {
                        sysUser.setFlag("1");
                    } else if (sysUser.getFlag().equals("离职")) {
                        sysUser.setFlag("2");
                    } else {
                        throw new CyServiceException(500, "数据错误");
                    }
                } else {
                    throw new CyServiceException(500, "数据错误");
                }

                //用户类型
                sysUser.setUserType("0");
                //身份
                sysUser.setIdentity("1");
                sysUserRepositorys.addSysUser(sysUser);
            }
        }
        return importUserDTO;
    }

    /**
     * @param persionId
     * @param userId
     * @return
     */
    @Override
    public boolean saveJieLinkId(String persionId, Integer userId) {
        /**
         * TODO 此处需要格局用户的主键ID将捷顺的主键ID存储进去
         * 此处未完成
         */
        SysUser modifyData = new SysUser();
        modifyData.setBusinessId(userId);
        modifyData.setPersonId(persionId);
        int i = sysUserRepositorys.saveJieLinkPersionId(modifyData);
        if (i > 0) {
            return true;
        } else {
            return false;
        }
    }

    @Override
    public String getPersionIdByUserId(Integer userId) {
        return sysUserRepositorys.getPersionIdByUserId(userId);
    }

    /**
     * 根据捷顺的ID查询用户信息
     *
     * @param personId
     * @return
     */
    @Override
    public SysUser getUserDataByPersonId(String personId) {
        return sysUserRepositorys.querySysUsersByPersonId(personId);
    }

    /**
     * 去除List中空数据
     *
     * @param list
     * @param <T>
     * @return
     * @throws Exception
     */
    public <T> List<T> ThrowNull(List<T> list) throws Exception {
        List<T> list2 = new ArrayList<>();
        if (list != null) {
            for (T t : list) {
                if (outNull(t) == true) {
                    list2.add(t);
                }
            }
        }
        return list2;
    }

    //只要有一个不为null则添加进去
    public boolean outNull(Object o) throws Exception {
        if (o != null) {
            Class aa = o.getClass();
            Field[] fields = aa.getDeclaredFields();
            for (Field field : fields) {//id
                field.setAccessible(true);
                if (field.get(o) != null && !field.getName().equals("rowNum")) {
                    return true;
                }
            }
        }
        return false;
    }

}
