package org.rcisoft.sys.sysuser.util;

import cn.hutool.core.util.ObjectUtil;
import org.apache.commons.lang3.StringUtils;
import org.rcisoft.core.constant.CySysCons;
import org.rcisoft.sys.sysuser.dto.ExportUserDTO;
import org.rcisoft.sys.sysuser.entity.SysUser;
import org.rcisoft.sys.visit.dto.ExportVisitInfoDto;
import org.rcisoft.sys.visit.dto.ExportVisitUserDTO;
import org.rcisoft.sys.wbac.user.dto.ErrorDTO;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

@ConditionalOnProperty(prefix = "cy.model", name = "permission", havingValue = CySysCons.WORK_BASE)
public class CheckUtil {


    /**
     * 对导入的用户信息进行非空校验
     *
     * @param sysUser 用户信息
     * @param row     行数
     * @return
     */
    public static ErrorDTO userNotNull(ExportUserDTO sysUser, int row) {
        ErrorDTO errorDTO = new ErrorDTO();
        Map<Integer, List<String>> notTrues = new HashMap<>();
        List<String> notTrue = new ArrayList<>();
        errorDTO.setSuccess(0);
        if (StringUtils.isEmpty(sysUser.getName())) {
            notTrue.add("姓名不能为空");
        }
        if (StringUtils.isEmpty(sysUser.getPhone())) {
            notTrue.add("手机号不能为空");
        }
        if (StringUtils.isEmpty(sysUser.getSex())) {
            notTrue.add("性别不能为空");
        }
        if (notTrue.size() > 0) {
            errorDTO.setSuccess(1);
            notTrues.put(row, notTrue);
            errorDTO.setMap(notTrues);
        }
        return errorDTO;
    }

    /**
     * 对导入信息进行查重校验
     *
     * @param sysUser  导入用户信息
     * @param row      行数
     * @param sysUsers 已有用户信息
     * @return
     */
    public static ErrorDTO userRepeat(ExportUserDTO sysUser, int row, List<SysUser> sysUsers) {
        ErrorDTO errorDTO = new ErrorDTO();
        Map<Integer, List<String>> notTrues = new HashMap<>();
        List<String> notTrue = new ArrayList<>();
        errorDTO.setSuccess(0);
        for (SysUser existenceUser : sysUsers) {
            if (existenceUser.getUsername().equals(sysUser.getUsername())) {
                notTrue.add("登录名不能重复");
            }
            if (existenceUser.getPhone().equals(sysUser.getPhone())) {
                notTrue.add("手机号不能重复");
            }
        }
        if (notTrue.size() > 0) {
            errorDTO.setSuccess(1);
            notTrues.put(row, notTrue);
            errorDTO.setMap(notTrues);
        }
        return errorDTO;
    }

    public static ErrorDTO infoNotNull(ExportVisitInfoDto visitInfoDto, int index) {
        ErrorDTO errorDTO = new ErrorDTO();
        Map<Integer, List<String>> notTrues = new HashMap<>();
        List<String> notTrue = new ArrayList<>();
        errorDTO.setSuccess(0);
        if (StringUtils.isEmpty(visitInfoDto.getUserName()))
            notTrue.add("发起人姓名不能为空");
        if (StringUtils.isEmpty(visitInfoDto.getPhone()))
            notTrue.add("发起人手机号不能为空");
        if (StringUtils.isEmpty(visitInfoDto.getVisitReason()))
            notTrue.add("访问事由不能为空");
        if (StringUtils.isEmpty(visitInfoDto.getVisitRegion()))
            notTrue.add("访问区域不能为空");
        if (ObjectUtil.isEmpty(visitInfoDto.getVisitDate()))
            notTrue.add("访问日期不能为空");
        if (StringUtils.isEmpty(visitInfoDto.getVisitTime()))
            notTrue.add("访问时间不能为空");
        if (StringUtils.isEmpty(visitInfoDto.getVisitName()))
            notTrue.add("访客姓名不能为空");
        if (StringUtils.isEmpty(visitInfoDto.getVisitPhone()))
            notTrue.add("访客手机号不能为空");
        // 判断访客姓名和手机号是否数量匹配
        List<String> userName = Arrays.asList(visitInfoDto.getVisitName().split(",")).stream()
                .filter(u -> StringUtils.isNotEmpty(u)).collect(Collectors.toList());
        List<String> phone = Arrays.asList(visitInfoDto.getVisitPhone().split(",")).stream()
                .filter(p -> StringUtils.isNotEmpty(p)).distinct()
                .collect(Collectors.toList());
        if (userName.size() != phone.size())
            notTrue.add("访客姓名和访客手机号数量不对应");
        List<String> matchList = phone.stream().filter(p -> p.matches("^1[3-9]\\d{9}$")).collect(Collectors.toList());
        if (matchList.size() < phone.size())
            notTrue.add("访客手机号不符合规范");
        if (notTrue.size() > 0) {
            errorDTO.setSuccess(1);
            notTrues.put(index, notTrue);
            errorDTO.setMap(notTrues);
        }
        return errorDTO;
    }

    public static ErrorDTO visvitNotNull(ExportVisitUserDTO sysUser, int index) {
        ErrorDTO errorDTO = new ErrorDTO();
        Map<Integer, List<String>> notTrues = new HashMap<>();
        List<String> notTrue = new ArrayList<>();
        errorDTO.setSuccess(0);
        if (StringUtils.isEmpty(sysUser.getName())) {
            notTrue.add("姓名不能为空");
        }
        if (StringUtils.isEmpty(sysUser.getPhone())) {
            notTrue.add("手机号不能为空");
        }
        if (notTrue.size() > 0) {
            errorDTO.setSuccess(1);
            notTrues.put(index, notTrue);
            errorDTO.setMap(notTrues);
        }
        return errorDTO;
    }
}
