package org.rcisoft.sys.visit.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.apache.commons.lang3.StringUtils;
import org.rcisoft.common.component.CyGlobal;
import org.rcisoft.core.component.CyDownErrorTxtComp;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.jwt.util.CyJwtUtil;
import org.rcisoft.core.util.CyCompareToolUtils;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.integration.jieLink.service.impl.JieLinkServiceImpl;
import org.rcisoft.sys.sysuser.dao.SysDeptRepositorys;
import org.rcisoft.sys.sysuser.dao.SysDictDataRepositorys;
import org.rcisoft.sys.sysuser.entity.SysDept;
import org.rcisoft.sys.sysuser.entity.SysDictData;
import org.rcisoft.sys.sysuser.entity.SysUser;
import org.rcisoft.sys.sysuser.service.impl.SysUserServiceImpl;
import org.rcisoft.sys.sysuser.util.CheckUtil;
import org.rcisoft.sys.sysuser.util.CyEpExcelUtil;
import org.rcisoft.sys.visit.dao.VisitInfomationRepository;
import org.rcisoft.sys.visit.dao.VisitPersonRepositorys;
import org.rcisoft.sys.visit.dao.VisitUserRepository;
import org.rcisoft.sys.visit.dto.ExportVisitInfoDto;
import org.rcisoft.sys.visit.dto.ImportVistInfoDTO;
import org.rcisoft.sys.visit.entity.CyResSvcExcEnum;
import org.rcisoft.sys.visit.entity.VisitInfoMation;
import org.rcisoft.sys.visit.entity.VisitUser;
import org.rcisoft.sys.visit.service.VisitInfomationService;
import org.rcisoft.sys.wbac.user.dto.ErrorDTO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.crypto.password.PasswordEncoder;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.rcisoft.core.model.CyPageInfo;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Calendar;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.UUID;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import java.util.stream.Collectors;

import lombok.extern.slf4j.Slf4j;
import org.springframework.util.CollectionUtils;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * Created by cy on 2022年11月16日 下午2:40:21.
 */
@Service
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class VisitInfomationServiceImpl extends ServiceImpl<VisitInfomationRepository, VisitInfoMation> implements VisitInfomationService {

    @Autowired
    VisitUserRepository visitUserRepository;

    @Autowired
    SysDictDataRepositorys sysDictDataRepositorys;

    @Autowired
    VisitPersonRepositorys sysUserRepositorys;

    @Autowired
    SysDeptRepositorys sysDeptRepositorys;

    @Autowired
    VisitUserServiceImpl userService;

    @Autowired
    private CyJwtUtil cyJwtUtil;

    @Autowired
    JieLinkServiceImpl jieLinkService;

    @Autowired
    private CyDownErrorTxtComp errorTxt;

    @Autowired
    private SysUserServiceImpl sysUserService;

    /**
     * 保存 邀访信息
     *
     * @param visitInfomation
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(VisitInfoMation visitInfomation) {
        //增加操作
        if (CollectionUtils.isEmpty(visitInfomation.getUserList()))
            throw new CyServiceException(500, "请至少新增一名访客");
        visitInfomation.setNormal();
        String[] regions = visitInfomation.getVisitRegions();
        String region = "";
        if (regions != null) {
            for (String r : regions) {
                region = region + r + ',';
            }
            if (region.length() > 0) {
                region = region.substring(0, region.length() - 1);
                visitInfomation.setVisitRegion(region);
            }
        }
        String[] regionCodes = visitInfomation.getVisitRegionCodes();
        String regionCode = "";
        if (regionCodes != null) {
            for (String code : regionCodes) {
                regionCode = regionCode + code + ",";
            }
            if (regionCode.length() > 0) {
                regionCode = regionCode.substring(0, regionCode.length() - 1);
                visitInfomation.setVisitRegionCode(regionCode);
            }
        }
        visitInfomation.setItemId(UUID.randomUUID().toString());
        int line = baseMapper.insert(visitInfomation);
        log.debug(CyUserUtil.getAuthenUsername() + "新增了ID为" +
                visitInfomation.getBusinessId() + "的邀访信息信息");
        // 添加访客信息
        visitInfomation.getUserList().forEach(u -> {
            // 判断当前访客(用户)是否已经存在
            SysUser sysUser = new SysUser();
            sysUser.setName(u.getUserName());
            sysUser.setPhone(u.getVisitPhone());
            sysUser.setUsername(u.getVisitPhone());
            sysUser.setNormal();
            List<SysUser> sysUserList = sysUserRepositorys.querySysUsers(sysUser);
            // 不存在新增
            if (CollectionUtils.isEmpty(sysUserList)) {
                sysUser.setPersonId(UUID.randomUUID().toString());
                sysUserRepositorys.insert(sysUser);
                u.setPersonId(sysUser.getPersonId());
                u.setUserId(sysUser.getBusinessId());
            } else {
                // 存在覆盖
                sysUser.setBusinessId(sysUserList.get(0).getBusinessId());
                sysUserRepositorys.updateSysUser(sysUser);
                u.setPersonId(sysUserList.get(0).getPersonId());
                u.setUserId(sysUserList.get(0).getBusinessId());
            }
            u.setVisitId(visitInfomation.getBusinessId());
            u.setNormal();
            visitUserRepository.insert(u);
        });
        //jieLinkService.pushVisitorData(visitInfomation);
        return new CyPersistModel(line);
    }

    /**
     * 删除 邀访信息
     *
     * @param visitInfomation
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(VisitInfoMation visitInfomation) {
        int line = baseMapper.realDelete(visitInfomation);
        log.debug(CyUserUtil.getAuthenUsername() + "删除了ID为" +
                visitInfomation.getBusinessId() + "的邀访信息信息");
        return new CyPersistModel(line);
    }
    /**
     * 禁用 邀访信息
     *
     * @param visitInfomation
     * @return
     */
    public CyPersistModel forbidden(VisitInfoMation visitInfomation){
        visitInfomation.setVisitStatus("2");
        int line = baseMapper.updateById(visitInfomation);
        return new CyPersistModel(line);
    }

    /**
     * 逻辑删除 邀访信息
     *
     * @param visitInfomation
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(VisitInfoMation visitInfomation) {
        visitInfomation.setDeleted();
        int line = baseMapper.deleteById(visitInfomation);
        log.debug(CyUserUtil.getAuthenUsername() + "逻辑删除了ID为" +
                visitInfomation.getBusinessId() + "的邀访信息信息");
        return new CyPersistModel(line);
    }

    /**
     * 修改 邀访信息
     *
     * @param visitInfomation
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(VisitInfoMation visitInfomation) {
        String regionCode = "";
        String region = "";
        for (String s : visitInfomation.getVisitRegionCodes()) {
            regionCode = regionCode + s + ',';
        }
        if (regionCode.length() > 0) {
            regionCode = regionCode.substring(0, regionCode.length() - 1);
            visitInfomation.setVisitRegionCode(regionCode);
        }

        for (String s : visitInfomation.getVisitRegions()) {
            region = region + s + ',';
        }
        if (regionCode.length() > 0) {
            region = region.substring(0, region.length() - 1);
            visitInfomation.setVisitRegion(region);
        }

        List<VisitUser> visitUsers = visitInfomation.getUserList();

        if (visitUsers.size() > 0) {
            userService.deleteByVisitId(visitInfomation.getBusinessId());
            for (VisitUser visitUser : visitUsers) {
                visitUser.setVisitId(visitInfomation.getBusinessId());
                userService.persist(visitUser);
            }
        }
        int line = baseMapper.updateById(visitInfomation);
        log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + visitInfomation.getBusinessId() + "的邀访信息信息");
        return new CyPersistModel(line);
    }

    /**
     * 根据id查询 邀访信息
     *
     * @param id
     * @return
     */
    @Override
    public VisitInfoMation findById(int id) {
        VisitInfoMation v = baseMapper.queryVisitById(id);
        if (v.getVisitRegionCode() != null) {
            String[] regionCodes = v.getVisitRegionCode().split(",");
            v.setVisitRegionCodes(regionCodes);
        }
        if (v.getVisitRegion() != null) {
            String[] regions = v.getVisitRegion().split(",");
            v.setVisitRegions(regions);
        }
        String vuList = "";
        for (VisitUser vu : v.getUserList()) {
            vuList = vuList + vu.getUserName() + ',';
        }
        if (vuList.length() > 0) {
            vuList = vuList.substring(0, vuList.length() - 1);
        }
        v.setUserArry(vuList);
        return v;
    }

    /**
     * 分页查询 邀访信息
     *
     * @param visitInfomation
     * @return
     */
    @Override
    public IPage<VisitInfoMation> findAllByPagination(CyPageInfo<VisitInfoMation> paginationUtility,
                                                      VisitInfoMation visitInfomation) {
        if (visitInfomation.getVisitReasonCode() != null && visitInfomation.getVisitReasonCode().length() > 0) {
            String[] reasonCodes = visitInfomation.getVisitReasonCode().split(",");
            for (String r : reasonCodes) {
                if (r.equals("other")) {
                    visitInfomation.setBoolExistOtherReason("YES");
                }
            }
            visitInfomation.setVisitReasonCodes(reasonCodes);
        }
        if (visitInfomation.getVisitRegionCode() != null && visitInfomation.getVisitRegionCode().length() > 0) {
            String[] regionCodes = visitInfomation.getVisitRegionCode().split(",");
            visitInfomation.setVisitRegionCodes(regionCodes);
        }
        IPage<VisitInfoMation> list = baseMapper.queryVisitInfomationsPaged(paginationUtility, visitInfomation);
        List<VisitInfoMation> mationList = list.getRecords();
        for (VisitInfoMation v : mationList) {
            if (v.getVisitRegionCode() != null) {
                String[] regionCodes = v.getVisitRegionCode().split(",");
                v.setVisitRegionCodes(regionCodes);
            }
            if (v.getVisitRegion() != null) {
                String[] regions = v.getVisitRegion().split(",");
                v.setVisitRegions(regions);
            }
            String vuList = "";
            String phoneList = "";
            for (VisitUser vu : v.getUserList()) {
                vuList = vuList + vu.getUserName() + ',';
                phoneList = phoneList + vu.getVisitPhone() + ',';
            }
            if (vuList.length() > 0) {
                vuList = vuList.substring(0, vuList.length() - 1);
                phoneList = phoneList.substring(0, phoneList.length() - 1);
            }
            v.setPhoneArry(phoneList);
            v.setUserArry(vuList);
        }
        list.setRecords(mationList);
        System.out.println(list);
        return baseMapper.queryVisitInfomationsPaged(paginationUtility, visitInfomation);

    }

    /**
     * 分页查询 邀访信息
     *
     * @param visitInfomation
     * @return
     */
    @Override
    public IPage<VisitInfoMation> findAllWithUserIdByPagination(CyPageInfo<VisitInfoMation> paginationUtility, VisitInfoMation visitInfomation, HttpServletRequest request) {
        //todo 获取用户id
        String tempUserId = CyUserUtil.getUserInfoStrProp(cyJwtUtil.getToken(request), CyUserUtil.USER_ID);
        //判断是否获取到当前用户id
        //如果没有当前用户id 返回空列表
        if (StringUtils.isEmpty(tempUserId)) {
            return null;
        }
        //userId 类型转换
        int userId = Integer.parseInt(tempUserId);
        /*
            根据id进行数据查询 然后处理进行放回 //新增接口,同时前端更换接口
         */
        if (visitInfomation.getVisitReasonCode() != null && visitInfomation.getVisitReasonCode().length() > 0) {
            String[] reasonCodes = visitInfomation.getVisitReasonCode().split(",");
            for (String r : reasonCodes) {
                if (r.equals("other")) {
                    visitInfomation.setBoolExistOtherReason("YES");
                }
            }
            visitInfomation.setVisitReasonCodes(reasonCodes);
        }
        if (visitInfomation.getVisitRegionCode() != null && visitInfomation.getVisitRegionCode().length() > 0) {
            String[] regionCodes = visitInfomation.getVisitRegionCode().split(",");
            visitInfomation.setVisitRegionCodes(regionCodes);
        }
        //调用mapper层方法进行查询
        IPage<VisitInfoMation> list = baseMapper.queryVisitInfomationsByUserIdPaged(paginationUtility, visitInfomation, userId);
        List<VisitInfoMation> mationList = list.getRecords();
        for (VisitInfoMation v : mationList) {
            if (v.getVisitRegionCode() != null) {
                String[] regionCodes = v.getVisitRegionCode().split(",");
                v.setVisitRegionCodes(regionCodes);
            }
            if (v.getVisitRegion() != null) {
                String[] regions = v.getVisitRegion().split(",");
                v.setVisitRegions(regions);
            }
            String vuList = "";
            for (VisitUser vu : v.getUserList()) {
                vuList = vuList + vu.getUserName() + ',';
            }
            if (vuList.length() > 0) {
                vuList = vuList.substring(0, vuList.length() - 1);
            }
            v.setUserArry(vuList);
        }
        list.setRecords(mationList);
//        System.out.println(list);
        return list;

    }

    /**
     * 查询list 邀访信息
     *
     * @param visitInfomation
     * @return
     */
    @Override
    public List<VisitInfoMation> findAll(VisitInfoMation visitInfomation) {
        List<VisitInfoMation> visitInfomationList = baseMapper.queryVisitList(visitInfomation);
        for (VisitInfoMation v : visitInfomationList) {
            String vuList = "";
            for (VisitUser vu : v.getUserList()) {
                vuList = vuList + vu.getUserName() + ',';
            }
            vuList = vuList.substring(0, vuList.length() - 1);
            v.setUserArry(vuList);
        }
        return visitInfomationList;
    }

    /**
     * 导出邀访信息
     *
     * @return
     */
    @Override
    public List<VisitInfoMation> export(VisitInfoMation visitInfomation) {
        List<VisitInfoMation> visitInfomationList = baseMapper.queryVisitList(visitInfomation);
        for (VisitInfoMation v : visitInfomationList) {
            String vuList = "";
            String phoneList = "";
            for (VisitUser vu : v.getUserList()) {
                vuList = vuList + vu.getUserName() + ',';
                phoneList = phoneList + vu.getVisitPhone() + ',';
            }
            if (vuList.length() > 0) {
                vuList = vuList.substring(0, vuList.length() - 1);
                phoneList = phoneList.substring(0, phoneList.length() - 1);
            }
            v.setUserArry(vuList);
            v.setPhoneArry(phoneList);
            if (v.getVisitStatus() != null) {
                if (v.getVisitStatus().equals("0")) {
                    v.setVisitStatus("未到访");
                }
                if (v.getVisitStatus().equals("1")) {
                    v.setVisitStatus("已访问");
                }
            }
        }
        return visitInfomationList;
    }

    /**
     * 获取当前用户最新受邀记录
     *
     * @return
     */
    @Override
    public VisitInfoMation lastDetail(HttpServletRequest request) {
        // 获取当前登录用户的手机号
        String phone = CyUserUtil.getUserInfoStrProp(cyJwtUtil.getToken(request), CyUserUtil.USER_PHONE);
        if (StringUtils.isEmpty(phone))
            return null;
        // 获取当前登录用户的受邀记录
        List<VisitInfoMation> visitInfList = baseMapper.lastDetail(phone);
        if (CollectionUtils.isEmpty(visitInfList) || visitInfList.size() == 0)
            return null;
        else
            return visitInfList.get(0);
    }

    /**
     * 获取最近两条邀请记录
     *
     * @param request
     * @return
     */
    @Override
    public List<VisitInfoMation> getPastOrFutureInfo(HttpServletRequest request) {

        //获取用户id
        String tempUserId = CyUserUtil.getUserInfoStrProp(cyJwtUtil.getToken(request), CyUserUtil.USER_ID);
//        System.out.println("用户id" + tempUserId);

        //判断是否获取到当前用户id
        //如果没有当前用户id 返回空列表
        if (StringUtils.isEmpty(tempUserId)) {
            return new ArrayList<>();
        }
        //userId 类型转换
        int userId = Integer.parseInt(tempUserId);
        List<VisitInfoMation> resList = new ArrayList<>();

        //根据当前用户id查找过去的邀请记录
        List<VisitInfoMation> pastList = baseMapper.queryPast(userId);
        int pastListLength = pastList.size();

        //根据当前用户id查找未来的邀请记录
        List<VisitInfoMation> futureList = baseMapper.queryFuture(userId);
        int futureListLength = futureList.size();

        if (pastListLength > 0 && futureListLength > 0) {
            resList.add(futureList.get(0));
            resList.add(pastList.get(0));
            return resList;
        }
        if (pastListLength == 0 && futureListLength > 1) {
            resList.add(futureList.get(1));
            resList.add(futureList.get(0));
            return resList;
        }
        if (pastListLength == 0 && futureListLength == 1) {
            resList.add(futureList.get(0));
            return resList;
        }
        if (pastListLength > 1 && futureListLength == 0) {
            resList.add(pastList.get(0));
            resList.add(pastList.get(1));
            return resList;
        }
        if (pastListLength == 1 && futureListLength == 0) {
            resList.add(pastList.get(0));
            return resList;
        }
        return resList;
    }

    @Override
    public int exportEmptyTemplate(HttpServletResponse response) {
        List<ExportVisitInfoDto> imOutSysUsers = new ArrayList<>();
        ExportVisitInfoDto exportUserDTO = new ExportVisitInfoDto();
        for (int i = 0; i < 500; i++) {
            imOutSysUsers.add(exportUserDTO);
        }
        CyEpExcelUtil.exportExcelSelect(imOutSysUsers, "邀访信息", "邀访",
                ExportVisitInfoDto.class, "邀访信息模板.xls", response, null);
        return 1;
    }

    @Override
    public ImportVistInfoDTO importUserExcel(MultipartFile file) throws ParseException {
        ImportVistInfoDTO importVistInfoDTO = new ImportVistInfoDTO();
        Calendar calendar = Calendar.getInstance();
        String nowTime = new SimpleDateFormat("yyyyMMddHHmmss").format(calendar.getTime());
        String fileName = "邀访错误信息" + nowTime + ".txt";
        List<Map<Integer, List<String>>> maps = new ArrayList<>();
        ExportVisitInfoDto exportVisitInfoDto = new ExportVisitInfoDto();
        boolean flag = false;
        try {
            flag = CyEpExcelUtil.isFileInUser(file, exportVisitInfoDto, 2);
        } catch (Exception e) {
            throw new CyServiceException(CyResSvcExcEnum.EXCEL_IMPORT_HEADER_ERROR);
        }
        if (!flag){
            throw new CyServiceException(CyResSvcExcEnum.EXCEL_IMPORT_HEADER_ERROR);
        }
        if (!flag || !CyCompareToolUtils.compareFileName(file, "邀访信息", 0, 0)) {
            String errorBefore = "上传模板错误请重新下载！";
            errorText(errorBefore, importVistInfoDTO, maps, fileName);
            try {
                errorTxt.exportTxtPaper(maps, fileName);
            } catch (Exception e) {
                throw new CyServiceException(CyResSvcExcEnum.EXCEL_IMPORT_HEADER_ERROR);
            }
            return importVistInfoDTO;
        }
        /** 从excel表中读到数据，有一部分为空值 */
        List<ExportVisitInfoDto> visitInfoDtoList = CyEpExcelUtil.importExcel(file, 2, 1, ExportVisitInfoDto.class);
        /** 校验后没有问题的数据 */
        List<ExportVisitInfoDto> addINfoList = new ArrayList<>();
        /** 遍历 从Excel表中读到的数据 抛出不合适的数据 */
        //判断整个Excel是不是为空 计算非空数据有多少条
        int information = CyCompareToolUtils.cmpareInformation(visitInfoDtoList);
        if (information == 0) {
            String errorBefore = "Excel文件不可为空，请检查Excel文件是否填写！";
            errorText(errorBefore, importVistInfoDTO, maps, fileName);
            try {
                errorTxt.exportTxtPaper(maps, fileName);
            } catch (Exception e) {
                throw new CyServiceException(CyResSvcExcEnum.ERROR_NETWORK);
            }
            return importVistInfoDTO;
        } else if (information > 500) {
            String errorMore = "单次导入数据不可超过500，请检查！";
            errorText(errorMore, importVistInfoDTO, maps, fileName);
            try {
                errorTxt.exportTxtPaper(maps, fileName);
            } catch (Exception e) {
                throw new CyServiceException(CyResSvcExcEnum.ERROR_NETWORK);
            }
            return importVistInfoDTO;
        } else {
            //去除空数据
            try {
                visitInfoDtoList = sysUserService.ThrowNull(visitInfoDtoList);
            } catch (Exception e) {
                throw new CyServiceException(CyResSvcExcEnum.ERROR_NETWORK);
            }
            //校验 将错误信息放入maps
            int index = 3; //从第3行开始
            for (ExportVisitInfoDto visitInfoDto : visitInfoDtoList) {
                //判断 是否为空
                ErrorDTO infoNull = CheckUtil.infoNotNull(visitInfoDto, index);
                if (infoNull.getSuccess() == 1)
                    maps.add(infoNull.getMap());
                else
                    addINfoList.add(visitInfoDto);
                index++;
            }
        }
        if (addINfoList.size() > 0) {
            for (ExportVisitInfoDto visitInfoDto : addINfoList) {

                VisitInfoMation visitInfoMation = new VisitInfoMation();
                // 根据姓名查询
                SysUser sysUserDTO = new SysUser();
                sysUserDTO.setDeleted();
                sysUserDTO.setName(visitInfoDto.getUserName());
                // 校验手机号
                Pattern pattern = Pattern.compile("^((13[0-9])|(14[0-9])|(15[0-9])|(16[0-9])|(17[0-9])|(18[0-9]))\\d{8}$+");
                if (visitInfoDto.getPhone().length() != 11) {
                    throw new CyServiceException(CyResSvcExcEnum.PHONE_DATA_ERROR);
                }
                Matcher m = pattern.matcher(visitInfoDto.getPhone());
                boolean isMatch = m.matches();
                if (!isMatch) {
                    throw new CyServiceException(CyResSvcExcEnum.PHONE_DATA_ERROR);
                }
                sysUserDTO.setPhone(visitInfoDto.getPhone());
                sysUserDTO.setUserType("0");
                // 根据姓名查询员工数据
                List<SysUser> sysUsers = sysUserRepositorys.querySysUsers(sysUserDTO);
                if (sysUsers.size() == 0) {
                    throw new CyServiceException(CyResSvcExcEnum.USER_DATA_ERROR);
                }
                SysUser mainUser = sysUsers.get(0);
                visitInfoMation.setUserId(mainUser.getBusinessId());
                visitInfoMation.setUserName(visitInfoDto.getUserName());
                // 设置邀访信息部门名称
                String deptId = mainUser.getDeptId();
                if (deptId != null) {
                    if (sysDeptRepositorys.queryDeptById(deptId).size() > 0) {
                        SysDept dept = sysDeptRepositorys.queryDeptById(deptId).get(0);
                        if (dept != null) {
                            String deptName = dept.getDeptName();
                            visitInfoMation.setDeptName(deptName);
                        }
                    }
                }
                // 设置邀访信息职位名称
                String position = mainUser.getPosition();
                if (position != null) {
                    SysDictData sysDictData = new SysDictData();
                    sysDictData.setDictType("position");
                    List<SysDictData> dictDataList = sysDictDataRepositorys.querySysDictDatas(sysDictData);
                    String postName = "";
                    for (SysDictData data : dictDataList) {
                        if (data.getDictValue().equals(position)) {
                            postName = data.getDictLabel();
                        }
                    }
                    visitInfoMation.setPostName(postName);
                }
                // 设置邀访信息访问事由
                String reason = visitInfoDto.getVisitReason();
                if (reason != null) {
                    SysDictData sysDictData = new SysDictData();
                    sysDictData.setDictType("visitReason");
                    List<SysDictData> dictDataList = sysDictDataRepositorys.querySysDictDatas(sysDictData);
                    String reasonCode = "";
                    for (SysDictData data : dictDataList) {
                        if (data.getDictLabel().equals(reason)) {
                            reasonCode = data.getDictValue();
                        }
                    }
                    if (reasonCode.equals("")) {
                        visitInfoMation.setVisitReasonCode("other");
                        visitInfoMation.setVisitReason("其他");
                        visitInfoMation.setVisitReasonOther(reason);
                    } else {
                        visitInfoMation.setVisitReason(reason);
                        visitInfoMation.setVisitReasonCode(reasonCode);
                    }
                }
                // 设置邀访信息访问区域
                if (visitInfoDto.getVisitRegion().length() > 0) {
                    String[] regions = visitInfoDto.getVisitRegion().split(",");
                    visitInfoMation.setVisitRegion(visitInfoDto.getVisitRegion());
                    String regionCode = "";
                    for (String region : regions) {
                        if (region.equals("行政办公楼")) {
                            regionCode = regionCode + "0" + ",";
                        } else {
                            regionCode = regionCode + "1" + ",";
                        }
                    }
                    if (regionCode.length() > 0) {
                        regionCode = regionCode.substring(0, regionCode.length() - 1);
                        visitInfoMation.setVisitRegionCode(regionCode);
                    }
                }
                visitInfoMation.setVisitRegion(visitInfoDto.getVisitRegion());
                SimpleDateFormat date = new SimpleDateFormat("yyyy-MM-dd");
                visitInfoMation.setVisitDate(date.parse(visitInfoDto.getVisitDate()));
                visitInfoMation.setVisitTime(visitInfoDto.getVisitTime());
                SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm");
                String time = visitInfoDto.getVisitDate().toString() + " " + visitInfoDto.getVisitTime();
                visitInfoMation.setVisitRealTime(dateFormat.parse(time));
                List<VisitUser> userList = new ArrayList<>();
                // 判断访客姓名和手机号是否数量匹配
                List<String> visitName = Arrays.asList(visitInfoDto.getVisitName().split(",")).stream()
                        .filter(u -> StringUtils.isNotEmpty(u)).collect(Collectors.toList());
                List<String> visitPhone = Arrays.asList(visitInfoDto.getVisitPhone().split(",")).stream()
                        .filter(p -> StringUtils.isNotEmpty(p)).distinct()
                        .collect(Collectors.toList());
                for (int i = 0; i < visitName.size(); i++) {
                    VisitUser visitUser = new VisitUser();
                    visitUser.setUserName(visitName.get(i));
                    visitUser.setVisitPhone(visitPhone.get(i));
                    userList.add(visitUser);
                }
                visitInfoMation.setUserList(userList);
                // 新增
                persist(visitInfoMation);
            }
        }
        if (null != maps && maps.size() > 0) {
            importVistInfoDTO.setFilename(fileName);
            try {
                errorTxt.exportTxtPaper(maps, fileName);
            } catch (Exception e) {
                throw new CyServiceException(CyResSvcExcEnum.ERROR_NETWORK);
            }
        }
        return importVistInfoDTO;
    }

    @Override
    public List<VisitInfoMation> findByUser(VisitUser visitUser) {
        return baseMapper.findByUser(visitUser);
    }


    void errorText(String error, ImportVistInfoDTO importVistInfoDTO, List<Map<Integer, List<String>>> maps, String fileName) {
        List<String> strings = new ArrayList<String>();
        strings.add(error);
        Map<Integer, List<String>> map = new HashMap<>();
        map.put(-1, strings);
        maps.add(map);
        importVistInfoDTO.setFilename(fileName);
    }
}
